@@ -33,17 +33,16 @@
 #include "proctable.h"
 #include "infoview.h"
 #include "procactions.h"
-#if 0
-#include "prettytable.h"
-#include "procdialogs.h"
-#include "memmaps.h"
-#include "favorites.h"
-#endif
 #include "load-graph.h"
+#include "cellrenderer.h"
+
+void	cb_toggle_tree (GtkMenuItem *menuitem, gpointer data);
+void	cb_toggle_threads (GtkMenuItem *menuitem, gpointer data);
+
 
 static GnomeUIInfo file1_menu_uiinfo[] =
 {
-	GNOMEUIINFO_MENU_EXIT_ITEM (cb_app_exit, NULL),
+	GNOMEUIINFO_MENU_QUIT_ITEM (cb_app_exit, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -88,11 +87,23 @@ static GnomeUIInfo view1_menu_uiinfo[] =
 	 cb_show_memory_maps, NULL, NULL, 0, 0,
 	 'm', GDK_CONTROL_MASK
 	},
+	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_TOGGLEITEM, N_("Process _Dependencies"), N_("Display a tree showing process dependencies"),
+	 cb_toggle_tree, NULL, NULL, 0, 0,
+	 'd', GDK_CONTROL_MASK
+	}, 
+	{
+	 GNOME_APP_UI_TOGGLEITEM, N_("_Threads"), N_("Display threads (subprocesses)"),
+	 cb_toggle_threads, NULL, NULL, 0, 0,
+	 't', GDK_CONTROL_MASK
+	}, 
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo help1_menu_uiinfo[] =
 {
+	GNOMEUIINFO_HELP("gnome-system-monitor"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM (cb_about_activate, NULL),
 	GNOMEUIINFO_END
 };
@@ -129,29 +140,29 @@ static GnomeUIInfo view_optionmenu[] =
 static GnomeUIInfo popup_menu_uiinfo[] =
 {
 	{
- 	  GNOME_APP_UI_ITEM, N_("Change Priority ..."), N_("Change the importance (nice value) of a process"),
+ 	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the importance (nice value) of a process"),
 	 popup_menu_renice, NULL, NULL, 0, 0,
 	 0, 0
 	},
 	{
- 	  GNOME_APP_UI_ITEM, N_("Memory Maps"), N_("View the memory maps associated with a process"),
+ 	  GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("View the memory maps associated with a process"),
 	 popup_menu_show_memory_maps, NULL, NULL, 0, 0,
 	 0, 0
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
- 	  GNOME_APP_UI_ITEM, N_("Hide Process"), N_("Hide a process"),
+ 	  GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide a process"),
 	 popup_menu_hide_process, NULL, NULL, 0, 0,
 	 0, 0
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
- 	  GNOME_APP_UI_ITEM, N_("End Process"), N_("Force a process to finish"),
+ 	  GNOME_APP_UI_ITEM, N_("_End Process"), N_("Force a process to finish"),
 	 popup_menu_end_process, NULL, NULL, 0, 0,
 	 0, 0
 	},
 	{
- 	  GNOME_APP_UI_ITEM, N_("Kill Process"), N_("Force a process to finish now"),
+ 	  GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish now"),
 	 popup_menu_kill_process, NULL, NULL, 0, 0,
 	 0, 0
 	},
@@ -188,15 +199,14 @@ create_proc_view (ProcData *procdata)
 	GtkWidget *label;
 	GtkWidget *hbox2;
 	
-	vbox1 = gtk_vbox_new (FALSE, 0);
+	vbox1 = gtk_vbox_new (FALSE, 18);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
 	
-	hbox1 = gtk_hbox_new (FALSE, 0);
+	hbox1 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox1), GNOME_PAD_SMALL);
 	
-	search_label = gtk_label_new_with_mnemonic (_("Sea_rch :"));
+	search_label = gtk_label_new_with_mnemonic (_("Sea_rch:"));
 	gtk_box_pack_start (GTK_BOX (hbox1), search_label, FALSE, FALSE, 0);
-	gtk_misc_set_padding (GTK_MISC (search_label), GNOME_PAD_SMALL, 0);
 	
 	search_entry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (hbox1), search_entry, FALSE, FALSE, 0);
@@ -214,19 +224,19 @@ create_proc_view (ProcData *procdata)
 	gtk_menu_set_active (GTK_MENU (optionmenu1_menu), procdata->config.whose_process);
   	gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu1), optionmenu1_menu);
   	  	
-  	label = gtk_label_new_with_mnemonic (_("Vie_w"));
+  	label = gtk_label_new_with_mnemonic (_("Vie_w:"));
   	gtk_label_set_mnemonic_widget (GTK_LABEL (label), optionmenu1);
 	gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
 	
 	gtk_widget_show_all (hbox1);
 	
 	scrolled = proctable_new (procdata);
 	if (!scrolled)
 		return NULL;
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+                                             GTK_SHADOW_IN);
 	
 	gtk_box_pack_start (GTK_BOX (vbox1), scrolled, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (scrolled), GNOME_PAD_SMALL);
 	
 	gtk_widget_show_all (scrolled);
 	
@@ -238,9 +248,6 @@ create_proc_view (ProcData *procdata)
 	
 	endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
   	gtk_box_pack_end (GTK_BOX (hbox2), endprocessbutton, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (endprocessbutton), GNOME_PAD_SMALL);
-	gtk_misc_set_padding (GTK_MISC (GTK_BIN (endprocessbutton)->child), 
-			      GNOME_PAD_SMALL, 1);
 	g_signal_connect (G_OBJECT (endprocessbutton), "clicked",
 			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 
@@ -248,8 +255,6 @@ create_proc_view (ProcData *procdata)
 	infobutton = gtk_button_new ();
 	gtk_container_add (GTK_CONTAINER (infobutton), infolabel);
 	gtk_box_pack_start (GTK_BOX (hbox2), infobutton, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (infobutton), GNOME_PAD_SMALL);
-	gtk_misc_set_padding (GTK_MISC (GTK_BIN (infobutton)->child), GNOME_PAD_SMALL, 1);
 	g_signal_connect (G_OBJECT (infobutton), "clicked",
 			  G_CALLBACK (cb_info_button_pressed), procdata);
 	
@@ -264,16 +269,69 @@ create_proc_view (ProcData *procdata)
         return vbox1;
 }
 
+static int
+sort_bytes (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer data)
+{
+	int col = GPOINTER_TO_INT (data);
+	float btotal1, btotal2, bfree1, bfree2;
+	float a, b;
+	
+	btotal1 = btotal2 = bfree1 = bfree2 = 0.0;
+	gtk_tree_model_get (model, itera, 7, &btotal1, 8, &bfree1, -1);
+	gtk_tree_model_get (model, iterb, 7, &btotal2, 8, &bfree2, -1);
+
+	switch (col)
+	{
+		case 4: 
+			a = btotal1;
+			b = btotal2;
+			break;
+		case 5: 
+			a = btotal1 - bfree1;
+			b = btotal2 - bfree2;
+			break;
+		case 6: 
+			a = bfree1;
+			b = bfree2;
+			break;
+		default:
+			a = 0;
+			b = 0;
+	}
+
+	if (a > b)
+		return -1;
+	else if (a < b)
+		return 1;
+	return 0;	
+}
+
+static GtkWidget *
+make_title_label (const char *text)
+{
+  GtkWidget *label;
+  char *full;
+
+  full = g_strdup_printf ("<span weight=\"bold\">%s</span>", text);
+  label = gtk_label_new (full);
+  g_free (full);
+
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+
+  return label;
+}
 
 static GtkWidget *
 create_sys_view (ProcData *procdata)
 {
 	GtkWidget *vbox;
 	GtkWidget *vpane;
-	GtkWidget *cpu_frame, *mem_frame;
-	GtkWidget *label,*cpu_label;
+	GtkWidget *cpu_box, *mem_box, *disk_box;
+	GtkWidget *cpu_hbox, *mem_hbox, *disk_hbox;
+	GtkWidget *cpu_graph_box, *mem_graph_box;
+	GtkWidget *label,*cpu_label, *spacer;
 	GtkWidget *hbox, *table;
-	GtkWidget *disk_frame;
 	GtkWidget *color_picker;
 	GtkWidget *scrolled;
 	GtkWidget *disk_tree;
@@ -282,9 +340,10 @@ create_sys_view (ProcData *procdata)
 	GtkCellRenderer *cell;
 	gchar *titles[5] = {_("Name"),
 			    _("Directory"),
-			    _("Used Space"),
-			    _("Total Space")
-			    };
+				_("Type"),
+			    _("Total"),
+			    _("Used"),
+				};
 	LoadGraph *cpu_graph, *mem_graph;
 	gint i;
 	
@@ -292,25 +351,36 @@ create_sys_view (ProcData *procdata)
 	sys_pane = vpane;
 	gtk_paned_set_position (GTK_PANED (vpane), procdata->config.pane_pos);
 	
-	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vpane), 6);
+
+	vbox = gtk_vbox_new (FALSE, 18);
 	gtk_paned_pack1 (GTK_PANED (vpane), vbox, TRUE, FALSE);
+
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+
+	/* The CPU BOX */
+
+	cpu_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), cpu_box, TRUE, TRUE, 0);
+
+	label = make_title_label (_("CPU History"));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (cpu_box), label, FALSE, FALSE, 0);
 	
-	cpu_frame = gtk_frame_new (_("% CPU Usage History"));
-	gtk_widget_show (cpu_frame);
-	gtk_container_set_border_width (GTK_CONTAINER (cpu_frame), GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX (vbox), cpu_frame, TRUE, TRUE, 0);
-	
-	mem_frame = gtk_frame_new (_("% Memory / Swap Usage History"));
-	gtk_container_set_border_width (GTK_CONTAINER (mem_frame), GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX (vbox), mem_frame, TRUE, TRUE, 0);
-	
+	cpu_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (cpu_box), cpu_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (cpu_hbox), spacer, FALSE, FALSE, 0);
+
+	cpu_graph_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (cpu_hbox), cpu_graph_box, TRUE, TRUE, 0);
+
 	cpu_graph = load_graph_new (CPU_GRAPH, procdata);
-	gtk_container_add (GTK_CONTAINER (cpu_frame), cpu_graph->main_widget);
-	gtk_container_set_border_width (GTK_CONTAINER (cpu_graph->main_widget), 
-					GNOME_PAD_SMALL);
-					
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (cpu_graph->main_widget), hbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (cpu_graph_box), cpu_graph->main_widget, TRUE, TRUE, 0);
+
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (cpu_graph_box), hbox, FALSE, FALSE, 0);
 
 	color_picker = gnome_color_picker_new ();
 	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
@@ -321,26 +391,45 @@ create_sys_view (ProcData *procdata)
 			    G_CALLBACK (cb_cpu_color_changed), procdata);
 	gtk_box_pack_start (GTK_BOX (hbox), color_picker, FALSE, FALSE, 0);
 	
-	label = gtk_label_new (_("CPU Used :"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
+	label = gtk_label_new (_("Used CPU:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
 	cpu_label = gtk_label_new ("");
-	gtk_misc_set_padding (GTK_MISC (cpu_label), GNOME_PAD_SMALL, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), cpu_label, FALSE, FALSE, 0);
 	cpu_graph->label = cpu_label;
 	
 	procdata->cpu_graph = cpu_graph;
+
+
+	/******************************************/
+
+	mem_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), mem_box, TRUE, TRUE, 0);
+
+	label = make_title_label (_("Memory and Swap History"));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (mem_box), label, FALSE, FALSE, 0);
 	
+	mem_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (mem_box), mem_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (mem_hbox), spacer, FALSE, FALSE, 0);
+
+	mem_graph_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (mem_hbox), mem_graph_box, TRUE, TRUE, 0);
+
+
 	mem_graph = load_graph_new (MEM_GRAPH, procdata);
-	gtk_container_add (GTK_CONTAINER (mem_frame), mem_graph->main_widget);
-	gtk_container_set_border_width (GTK_CONTAINER (mem_graph->main_widget), 
-					GNOME_PAD_SMALL);
-	
+	gtk_box_pack_start (GTK_BOX (mem_graph_box), mem_graph->main_widget, 
+			    TRUE, TRUE, 0);
 	
 	table = gtk_table_new (2, 6, FALSE);
-	gtk_box_pack_start (GTK_BOX (mem_graph->main_widget), table, FALSE, FALSE, 0);
-	
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+	gtk_box_pack_start (GTK_BOX (mem_graph_box), table, 
+			    FALSE, FALSE, 0);
+
 	color_picker = gnome_color_picker_new ();
 	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
 				    mem_graph->colors[2].red,
@@ -350,31 +439,22 @@ create_sys_view (ProcData *procdata)
 			    G_CALLBACK (cb_mem_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
 	
-	label = gtk_label_new (_("Memory"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
+	label = gtk_label_new (_("Used memory:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
 	
-	label = gtk_label_new (_("Used :"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_FILL, 0, 0, 0);
-	
 	mem_graph->memused_label = gtk_label_new ("");
-	gtk_misc_set_padding (GTK_MISC (mem_graph->memused_label), GNOME_PAD_SMALL, 0);
 	gtk_misc_set_alignment (GTK_MISC (mem_graph->memused_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->memused_label, 3, 4, 0, 1, 
+	gtk_table_attach (GTK_TABLE (table), mem_graph->memused_label, 2, 3, 0, 1, 
 			  GTK_FILL, 0, 0, 0);
 	
-	label = gtk_label_new (_("Total :"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
+	label = gtk_label_new (_("of"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_FILL, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, 0, 0, 0);
 	
 	mem_graph->memtotal_label = gtk_label_new ("");
-	gtk_misc_set_padding (GTK_MISC (mem_graph->memtotal_label), GNOME_PAD_SMALL, 0);
 	gtk_misc_set_alignment (GTK_MISC (mem_graph->memtotal_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->memtotal_label, 5, 6, 0, 1, 
+	gtk_table_attach (GTK_TABLE (table), mem_graph->memtotal_label, 4, 5, 0, 1, 
 			  GTK_FILL, 0, 0, 0);
 	
 	color_picker = gnome_color_picker_new ();
@@ -386,50 +466,58 @@ create_sys_view (ProcData *procdata)
 			    G_CALLBACK (cb_swap_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
 			  
-	label = gtk_label_new (_("Swap"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
+	label = gtk_label_new (_("Used swap:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
 	
-	label = gtk_label_new (_("Used :"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, 1, 2, GTK_FILL, 0, 0, 0);
-	
 	mem_graph->swapused_label = gtk_label_new ("");
-	gtk_misc_set_padding (GTK_MISC (mem_graph->swapused_label), GNOME_PAD_SMALL, 0);
 	gtk_misc_set_alignment (GTK_MISC (mem_graph->swapused_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swapused_label, 3, 4, 1, 2, 
+	gtk_table_attach (GTK_TABLE (table), mem_graph->swapused_label, 2, 3, 1, 2, 
 			  GTK_FILL, 0, 0, 0);
 			  
-	label = gtk_label_new (_("Total :"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
+	label = gtk_label_new (_("of"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 4, 5, 1, 2, GTK_FILL, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 1, 2, GTK_FILL, 0, 0, 0);
 	
 	mem_graph->swaptotal_label = gtk_label_new ("");
-	gtk_misc_set_padding (GTK_MISC (mem_graph->swaptotal_label), GNOME_PAD_SMALL, 0);
 	gtk_misc_set_alignment (GTK_MISC (mem_graph->swaptotal_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swaptotal_label, 5, 6, 1, 2, 
+	gtk_table_attach (GTK_TABLE (table), mem_graph->swaptotal_label, 4, 5, 1, 2, 
 			  GTK_FILL, 0, 0, 0);	
 	
 	procdata->mem_graph = mem_graph;
 	gtk_widget_show_all (vbox);
-				
-	disk_frame = gtk_frame_new (_("Devices"));
-	gtk_container_set_border_width (GTK_CONTAINER (disk_frame), GNOME_PAD_SMALL);
 
-	gtk_paned_pack2 (GTK_PANED (vpane), disk_frame, TRUE, TRUE);
-	
+
+	/*****************************************/
+
+	disk_box = gtk_vbox_new (FALSE, 6);
+
+	gtk_container_set_border_width (GTK_CONTAINER (disk_box), 6);
+
+	gtk_paned_pack2 (GTK_PANED (vpane), disk_box, TRUE, TRUE);
+
+	label = make_title_label (_("Devices"));
+	gtk_box_pack_start (GTK_BOX (disk_box), label, FALSE, FALSE, 0);
+
+	disk_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (disk_box), disk_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (disk_hbox), spacer, FALSE, FALSE, 0);
+
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled), 
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_container_set_border_width (GTK_CONTAINER (scrolled), GNOME_PAD_SMALL);
-	gtk_container_add (GTK_CONTAINER (disk_frame), scrolled);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+                                             GTK_SHADOW_IN);
+
+	gtk_box_pack_start (GTK_BOX (disk_hbox), scrolled, TRUE, TRUE, 0);
+
 	 
-	model = gtk_tree_store_new (5, G_TYPE_STRING, G_TYPE_STRING,
+	model = gtk_tree_store_new (9, GDK_TYPE_PIXBUF, G_TYPE_STRING, 
+					   G_TYPE_STRING, G_TYPE_STRING,
 				       G_TYPE_STRING, G_TYPE_STRING,
-				       G_TYPE_STRING); 
+					G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_FLOAT);
 				       
 	disk_tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
 	procdata->disk_list = disk_tree;
@@ -437,19 +525,62 @@ create_sys_view (ProcData *procdata)
   	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (disk_tree), TRUE);
   	g_object_unref (G_OBJECT (model));
   	
-  	for (i = 0; i < 4; i++) {
+ 	col = gtk_tree_view_column_new ();
+  	cell = gtk_cell_renderer_pixbuf_new ();
+	gtk_tree_view_column_pack_start (col, cell, FALSE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "pixbuf", 0,
+					     NULL);
+		
+	cell = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (col, cell, FALSE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "text", 1,
+					     NULL);
+	gtk_tree_view_column_set_title (col, titles[0]);
+	gtk_tree_view_column_set_sort_column_id (col, 1);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
+								
+  	for (i = 1; i < 4	; i++) {
   		cell = gtk_cell_renderer_text_new ();
   		col = gtk_tree_view_column_new_with_attributes (titles[i],
 						    		cell,
-						     		"text", i,
+						     		"text", i + 1,
 						     		NULL);
 		gtk_tree_view_column_set_resizable (col, TRUE);
+		gtk_tree_view_column_set_sort_column_id (col, i + 1);
 		gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
 	}
+	
+	col = gtk_tree_view_column_new ();	
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (col, cell, FALSE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "text", 5,
+					     NULL);
+	gtk_tree_view_column_set_title (col, _(titles[4]));
+		
+	
+	cell = gtk_cell_renderer_progress_new ();
+	gtk_tree_view_column_pack_start (col, cell, TRUE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "value", 6,
+					     NULL);
+	
+	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_sort_column_id (col, 5);
+	
+	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+					 4, sort_bytes, GINT_TO_POINTER (4), NULL);
+	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+					 5, sort_bytes, GINT_TO_POINTER (5), NULL);
+	
+	gtk_widget_show_all (disk_box);
   	
-	gtk_widget_show_all (disk_frame);
-  	
-  	procman_get_tree_state (procdata->client, disk_tree, "/apps/procman/disktree");
+  	procman_get_tree_state (procdata->client, disk_tree, "/apps/procman/disktreenew");
   	
   	cb_update_disks (procdata);
   	procdata->disk_timeout = gtk_timeout_add (procdata->config.disks_update_interval,
@@ -475,21 +606,20 @@ create_main_window (ProcData *procdata)
 	width = procdata->config.width;
 	height = procdata->config.height;
 	gtk_window_set_default_size (GTK_WINDOW (app), width, height);
-	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, TRUE);
+	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 	
 	gnome_app_create_menus_with_data (GNOME_APP (app), menubar1_uiinfo, procdata);
 	
 	notebook = gtk_notebook_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (notebook), GNOME_PAD_SMALL);
-
+	
 	vbox1 = create_proc_view (procdata);
-	tab_label1 = gtk_label_new_with_mnemonic (_("Process _Listing"));
+	tab_label1 = gtk_label_new (_("Process Listing"));
 	gtk_widget_show (tab_label1);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox1, tab_label1);
 	
 	sys_box = create_sys_view (procdata);
 	gtk_widget_show (sys_box);
-	tab_label2 = gtk_label_new_with_mnemonic (_("System _Monitor"));
+	tab_label2 = gtk_label_new_with_mnemonic (_("Resource Monitor"));
 	gtk_widget_show (tab_label2);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label2);
 	
@@ -524,6 +654,10 @@ create_main_window (ProcData *procdata)
  	toggle_infoview (procdata);
 
  	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab);
+ 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[2].widget),
+							  procdata->config.show_tree);
+ 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[3].widget),
+							  procdata->config.show_threads);
 	
  	return app;
 
@@ -547,10 +681,6 @@ create_simple_view_dialog (ProcData *procdata)
 	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
 	gtk_window_set_default_size (GTK_WINDOW (app), 350, 425);
 	
-	accel = gtk_accel_group_new ();
-	gtk_accel_group_attach (accel, G_OBJECT (app));
-	gtk_accel_group_unref (accel);
-	
 	main_vbox = GNOME_DIALOG (app)->vbox;
 	
 	frame = gtk_frame_new (_("Running Applications"));
@@ -660,5 +790,36 @@ update_sensitivity (ProcData *data, gboolean sensitivity)
 		gtk_widget_set_sensitive (edit1_menu_uiinfo[3].widget, sensitivity);
 		gtk_widget_set_sensitive (edit1_menu_uiinfo[4].widget, sensitivity);
 	}
-}	
+}
 
+void		
+cb_toggle_tree (GtkMenuItem *menuitem, gpointer data)
+{
+	ProcData *procdata = data;
+	GtkCheckMenuItem *menu = GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[2].widget);
+	GConfClient *client = procdata->client;
+	gboolean show;
+	
+	show = gtk_check_menu_item_get_active (menu);
+	if (show == procdata->config.show_tree)
+		return;
+		
+	gconf_client_set_bool (client, "/apps/procman/show_tree", show, NULL);
+	
+}
+
+void		
+cb_toggle_threads (GtkMenuItem *menuitem, gpointer data)
+{
+	ProcData *procdata = data;
+	GtkCheckMenuItem *menu = GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[3].widget);
+	GConfClient *client = procdata->client;
+	gboolean show;
+	
+	show = gtk_check_menu_item_get_active (menu);
+	if (show == procdata->config.show_threads)
+		return;
+		
+	gconf_client_set_bool (client, "/apps/procman/show_threads", show, NULL);
+	
+}
