@@ -24,7 +24,6 @@
 #include <string.h>
 #include <glibtop.h>
 #include <glibtop/proclist.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/procstate.h>
 #include <glibtop/procmem.h>
 #include <glibtop/proctime.h>
@@ -127,7 +126,9 @@ proctable_new (ProcData *data)
 				 N_("User"), N_("Status"),
 				 N_("Memory"), N_("VM Size"), N_("Resident Memory"),
 				 N_("Shared Memory"), N_("RSS Memory"),
-				 N_("% CPU"), N_("Nice"), N_("ID"), NULL, "POINTER"};
+				 /* xgettext:no-c-format */
+				 N_("% CPU"),
+				 N_("Nice"), N_("ID"), NULL, "POINTER"};
 	gint i;
 	
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -162,7 +163,7 @@ proctable_new (ProcData *data)
 	gtk_tree_view_column_set_attributes (column, cell_renderer,
 					     "text", COL_NAME,
 					     NULL);
-	gtk_tree_view_column_set_title (column, title[0]);
+	gtk_tree_view_column_set_title (column, _(title[0]));
 	gtk_tree_view_column_set_sort_column_id (column, COL_NAME);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (proctree), column);
@@ -170,7 +171,7 @@ proctable_new (ProcData *data)
   	
   	for (i = 1; i < NUM_COLUMNS - 2; i++) {
   		cell_renderer = gtk_cell_renderer_text_new ();
-  		column = gtk_tree_view_column_new_with_attributes (title[i],
+  		column = gtk_tree_view_column_new_with_attributes (_(title[i]),
 						    		   cell_renderer,
 						     		   "text", i,
 						     		   NULL);
@@ -252,8 +253,6 @@ proctable_free_info (ProcInfo *info)
 		g_free (info->user);
 	if (info->status)
 		g_free (info->status);
-	if (info->pixbuf)
-		g_object_unref (info->pixbuf);
 	g_free (info);
 }
 
@@ -365,13 +364,13 @@ is_graphical (ProcInfo *info)
 		if (memmaps [i].flags & (1 << GLIBTOP_MAP_ENTRY_FILENAME)) {
 			string = strstr (memmaps[i].filename, "libX11");
 			if (string) {
-				glibtop_free (memmaps);
+				g_free (memmaps);
 				return TRUE;
 			}
 		}
 	}
 	
-	glibtop_free (memmaps);
+	g_free (memmaps);
 	
 	return FALSE;
 }
@@ -483,6 +482,8 @@ remove_children_from_tree (ProcData *procdata, GtkTreeModel *model,
 		
 		gtk_tree_model_get (model, parent, COL_POINTER, &child_info, -1);
 		if (child_info) {
+			if (procdata->selected_process == child_info) 
+				procdata->selected_process = NULL;
 			procdata->info = g_list_remove (procdata->info, child_info);
 			proctable_free_info (child_info);
 		}
@@ -496,7 +497,6 @@ remove_info_from_tree (ProcInfo *info, ProcData *procdata)
 	GtkTreeModel *model;
 	GtkTreeIter iter, child;
 	GtkTreePath *node;
-	gboolean selected = FALSE;
 	
 	g_return_if_fail (info);
 	
@@ -511,16 +511,10 @@ remove_info_from_tree (ProcInfo *info, ProcData *procdata)
 		remove_children_from_tree (procdata, model, &child);
 	
 	if (procdata->selected_process == info) 
-		selected = TRUE;
+		procdata->selected_process = NULL;
 	
 	gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
 	
-	if (selected) {
-		node = gtk_tree_model_get_path (model, &iter);
-		gtk_tree_view_set_cursor (GTK_TREE_VIEW (procdata->tree), node, NULL, FALSE);
-		gtk_tree_path_free (node);
-	}
-	
 	info->visible = FALSE;	
 		
 }
@@ -529,6 +523,7 @@ static void
 update_info (ProcData *procdata, ProcInfo *info, gint pid)
 {
 	GtkTreeModel *model;
+	GtkTreePath *path;
 	glibtop_proc_state procstate;
 	glibtop_proc_mem procmem;
 	glibtop_proc_uid procuid;
@@ -576,11 +571,22 @@ update_info (ProcData *procdata, ProcInfo *info, gint pid)
 	}
 	
 	if (info->visible) {
+		GdkRectangle rect, vis_rect;
+		path = gtk_tree_model_get_path (model, &info->node);
+		gtk_tree_view_get_cell_area (GTK_TREE_VIEW (procdata->tree),
+								      path, 	NULL, &rect);
+		gtk_tree_view_get_visible_rect (GTK_TREE_VIEW (procdata->tree),
+									   &vis_rect);
+		gtk_tree_path_free (path);
+		/* Don't update if row is not visible. Small performance improvement */
+		if ((rect.y < 0) || (rect.y > vis_rect.height))
+			return;
 		mem = get_size_string (info->mem);
 		vmsize = get_size_string (info->vmsize);
 		memres = get_size_string (info->memres);
 		memshared = get_size_string (info->memshared);
 		memrss = get_size_string (info->memrss);
+		
 		gtk_tree_store_set (GTK_TREE_STORE (model), &info->node, 
 				    COL_STATUS, info->status,
 				    COL_MEM, mem,
@@ -633,12 +639,15 @@ get_info (ProcData *procdata, gint pid)
 				arguments[i] = ' ';
 		}
 		info->arguments = g_strdup (arguments);
-		glibtop_free (arguments);
+		g_free (arguments);
 	}
 	else
 		info->arguments = g_strdup ("");
 	
-	info->user = g_strdup_printf ("%s", pwd->pw_name);
+	if (pwd && pwd->pw_name)
+		info->user = g_strdup_printf ("%s", pwd->pw_name);
+	else
+		info->user = NULL;
 	info->mem = procmem.size;
 	info->vmsize = procmem.vsize;
 	info->memres = procmem.resident;
@@ -815,7 +824,7 @@ proctable_update_list (ProcData *data)
 	
 	refresh_list (procdata, pid_list, n);
 	
-	glibtop_free (pid_list);
+	g_free (pid_list);
 	
 }
 
@@ -913,7 +922,7 @@ proctable_search_table (ProcData *procdata, gchar *string)
 			gtk_tree_path_free (node);
 		}
 		
-		if (strstr (info->user, string) && info->visible)
+		if (info->user && strstr (info->user, string) && info->visible)
 		{
 			GtkTreePath *node = gtk_tree_model_get_path (model, &info->node);
 			
